@@ -5,7 +5,7 @@ use warnings;
 package Acme::ConspiracyTheory::Random;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use Exporter::Shiny qw( theory );
 use List::Util 1.54 ();
@@ -547,10 +547,22 @@ sub misinformation {
 			my $place = random_place( $orig_meta );
 			"$place is real";
 		},
-		'the Earth is 4.5 billion years old',
-		'the universe is 14 billion years old',
-		'dinosaurs are real',
-		'birds are real',
+		sub {
+			$orig_meta->{topic} = { name => 'carbon dating', plural => 0 };
+			'the Earth is 4.5 billion years old';
+		},
+		sub {
+			$orig_meta->{topic} = { name => 'radiocarbon dating', plural => 0 };
+			'the universe is 14 billion years old';
+		},
+		sub {
+			$orig_meta->{topic} = { name => 'pigeons', plural => 1 };
+			'dinosaurs are real';
+		},
+		sub {
+			$orig_meta->{topic} = { name => 'surveillance drones', plural => 1 };
+			'birds are real';
+		},
 	);
 	
 	_MERGE_( $orig_meta, misinformation => $info );
@@ -1002,6 +1014,19 @@ sub hidden_truth {
 				'the USA used to have 52 states',
 			);
 		},
+		sub {
+			$orig_meta->{topic} = { name => 'the crusades', plural => 1 };
+			my $subst = _RANDOM_(
+				'TikTok',
+				'Twitter',
+				'the world wars',
+				'intergalactic warfare',
+				'the white genocide',
+				'colonization',
+				'robot wars',
+			);
+			"the crusades never stopped, they were just replaced with $subst";
+		},
 		sub {
 			my $cryptids = cryptids( $orig_meta );
 			"$cryptids are real";
@@ -1224,6 +1249,11 @@ sub theory {
 				'',
 				" But the truth shall not be buried!",
 				" Don't let yourself be deceived!",
+				" Take the red pill!",
+				" Believing $misinfo is taking the blue pill!",
+				" Take the red pill - $truth!",
+				" Believing $misinfo is for blue pill sheeple!",
+				" Open your mind!",
 			);
 			
 			_UCFIRST_ "$group $is spreading the lie that $misinfo to distract the public from the truth that $truth.$exclaim";
@@ -1252,6 +1282,7 @@ sub theory {
 							my $badplace = bad_place( $orig_meta );
 							"has their mind wiped at $badplace";
 						},
+						'is given a blue pill',
 					);
 					"Everybody who finds out why $consequence";
 				},
@@ -1284,6 +1315,7 @@ sub theory {
 				"$victim found out because they were the source of all knowledge",
 				"$victim found out using time travel",
 				"$victim found out using mind reading",
+				"$victim took the red pill",
 			);
 			
 			_UCFIRST_ "$group killed $victim to hide the truth that $truth. $explanation.";
@@ -1327,13 +1359,26 @@ sub theory {
 				},
 			);
 			
-			_UCFIRST_ "$truth but nobody knows because $sheeple.";
+			_UCFIRST_ _RANDOM_(
+				"$truth but nobody knows because $sheeple.",
+				"$truth but nobody believes me because $sheeple.",
+				"$truth but everybody ignores it because $sheeple.",
+				"$truth but people are blind because $sheeple.",
+			);
 		},
 		sub {
 			my $fiction = fiction( $orig_meta );
 			my $truth = hidden_truth( $orig_meta );
 			
-			_UCFIRST_ "$fiction has a hidden message that $truth.";
+			_UCFIRST_ _RANDOM_(
+				"$fiction has a hidden message that $truth.",
+				"$fiction is just an allegory which shows that $truth.",
+				sub {
+					my $group = shady_group( $orig_meta );
+					$orig_meta->{protagonists} //= $orig_meta->{shady_group};
+					"$fiction was analysed with a computer by $group and it revealed $truth.",
+				},
+			);
 		},
 		sub {
 			my $group = shady_group( $orig_meta );
@@ -1343,16 +1388,52 @@ sub theory {
 			my $place    = random_place( $orig_meta );
 			my $darklord = dark_lord( $orig_meta );
 			
-			_UCFIRST_ "$group $are abducting orphan children from $place to sacrifice them to $darklord.";
+			my $getting_kids = _RANDOM_(
+				'abducting orphan children',
+				'buying child slaves',
+				'cloning babies',
+				'growing babies in test tubes',
+				'breeding babies',
+				'buying kids from poor families',
+				'stealing babies',
+				sub {
+					$orig_meta->{topic} //= { name => 'adoption', plural => 0 };
+					'adopting babies';
+				},
+				sub {
+					$orig_meta->{topic} //= { name => 'adoption', plural => 0 };
+					'adopting kids';
+				},
+			);
+			
+			my $sacrifice = _RANDOM_(
+				'sacrifice them',
+				'ritually sacrifice them',
+				'offer them',
+				'offer them as a blood sacrifice',
+				'offer them as brides',
+				'offer them as sex slaves',
+				'feed them',
+				'sell them',
+				'mass sacrifice them',
+			);
+			
+			_UCFIRST_ "$group $are $getting_kids in $place to $sacrifice to $darklord.";
 		},
 		sub {
 			my $group = shady_group( $orig_meta );
 			$orig_meta->{protagonists} = $orig_meta->{shady_group};
 			my $have = $orig_meta->{protagonists}->{plural} ? 'have' : 'has';
+			my $are  = $orig_meta->{protagonists}->{plural} ? 'are'  : 'is';
 			
 			my $resource = precious_resource_with_quantity( $orig_meta );
 			
-			_UCFIRST_ "$group $have $resource.";
+			_UCFIRST_ _RANDOM_(
+				"$group $have $resource.",
+				"$group $are trying to obtain $resource.",
+				"$group $are in possession of $resource.",
+				"$group $have taken a delivery of $resource.",
+			);
 		},
 		sub {
 			my $group = shady_group( $orig_meta );
@@ -1410,6 +1491,14 @@ sub theory {
 					$orig_meta->{topic} = { name => 'Satan', plural => 0 };
 					'the axis of evil in the cosmic microwave background was put there by Satan';
 				},
+				sub {
+					$orig_meta->{topic} = { name => 'the zodiac', plural => 0 };
+					'astrology has been scientifically verified';
+				},
+				sub {
+					$orig_meta->{topic} = { name => 'the year of the dragon', plural => 0 };
+					'the Chinese zodiac can predict the future';
+				},
 			);
 			
 			my $solution = _UCFIRST_ _RANDOM_(
@@ -1513,7 +1602,12 @@ sub theory {
 			my $place  = random_place( $orig_meta );
 			my $truth1 = hidden_truth( $orig_meta );
 			
-			_UCFIRST_ "It is common knowledge in $place that $truth1.";
+			_UCFIRST_ _RANDOM_(
+				"It is common knowledge in $place that $truth1.",
+				"They teach $truth1 at schools in $place.",
+				"Everybody in $place knows that $truth1.",
+				"People in $place found out that $truth1.",
+			);
 		},
 		sub {
 			my $celeb  = celebrity( $orig_meta );
@@ -1542,7 +1636,14 @@ sub theory {
 			my $group = shady_group( $orig_meta );
 			$orig_meta->{protagonists} = $orig_meta->{shady_group};
 			
-			_UCFIRST_ "$celeb is a member of $group.";
+			_UCFIRST_ _RANDOM_(
+				"$celeb is a member of $group.",
+				"$celeb is a former member of $group.",
+				"$celeb was thrown out of $group.",
+				"$celeb infiltrated $group.",
+				"$celeb is the leader of $group.",
+				"$celeb is secretly worshipped by $group.",
+			);
 		},
 	);
 
